@@ -18,7 +18,7 @@
 ** Foundation and appearing in the file LICENSE.LGPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** will be met: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain
 ** additional rights. These rights are described in the Nokia Qt LGPL
@@ -31,7 +31,7 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** If you are unsure which license is appropriate for your use, please
 ** contact the sales department at qt-sales@nokia.com.
@@ -40,7 +40,7 @@
 ****************************************************************************/
 
 //#define QPROCESS_DEBUG
-
+#include <QElapsedTimer>
 #if defined QPROCESS_DEBUG
 #include <qdebug.h>
 #include <QString>
@@ -192,7 +192,7 @@ void K3bQProcessPrivate::Channel::clear()
     QProcess can merge the two output channels, so that standard
     output and standard error data from the running process both use
     the standard output channel. Call setProcessChannelMode() with
-    MergedChannels before starting the process to activative
+    MergedChannels before starting the process to activate
     this feature. You also have the option of forwarding the output of
     the running process to the calling, main process, by passing
     ForwardedChannels as the argument.
@@ -1380,7 +1380,7 @@ bool K3bQProcess::waitForBytesWritten(int msecs)
     if (d->processState == ::QProcess::NotRunning)
         return false;
     if (d->processState == ::QProcess::Starting) {
-        QTime stopWatch;
+        QElapsedTimer stopWatch;
         stopWatch.start();
         bool started = waitForStarted(msecs);
         if (!started)
@@ -1416,7 +1416,7 @@ bool K3bQProcess::waitForFinished(int msecs)
     if (d->processState == ::QProcess::NotRunning)
         return false;
     if (d->processState == ::QProcess::Starting) {
-        QTime stopWatch;
+        QElapsedTimer stopWatch;
         stopWatch.start();
         bool started = waitForStarted(msecs);
         if (!started)
